from setuptools import setup

setup(
    name='pygameextra',
    entry_points={
        'console_scripts': [
            'PGE = PGE:PE___entry___PE',
        ],
    }
)
